/**---------------------------------------------------------------------
***    
***    file:        pathtest.c
***
***    project:    Motif Widgets example programs
***
***    description:    This program creates a push button widget and
***                 three label widgets, all contained within a
***                 bulletin board widget.  The labels that are
***                 displayed are dependent on the setting of certain
***                 environment variables, LANG, XAPPLRESDIR, 
***                 XFILESEARCHPATH, and XUSERFILESEARCHPATH.
***
***-------------------------------------------------------------------*/
/*
 * Pathtest app-defaults file for this program
 *

!
!    Pathtest app-defaults file for Motif demo programs
!
!    general appearance and behavior defaults
!
*keyboardFocusPolicy:    POINTER
*fontList:            courB12
*borderWidth:            2
*shadowThickness:        3
*height:    240
*width:        350
!
!  BulletinBoard resources
!
*XmBulletinBoard.background:    light blue
!
!  PushButton resources
!
*XmPushButton.foreground:    goldenrod
*XmPushButton.background:    midnight blue
*XmPushButton.borderWidth:    0
*XmPushButton.height:    30
*XmPushButton.width:    100
*XmPushButton.x:    125
*XmPushButton.y:    30
!
!  Label resources
!
*label1.labelString:    /usr/lib/X11/app-defaults/Pathtest
*label1.x:    10
*label1.y:    90
*label1.height:    30
*label1.width:    320
*label1.marginHeight:    0
*label1.marginWidth:    0
*label1.fontList:            courB12
!*label2.labelString:    /usr/lib/X11/app-defaults/Pathtest
*label2.x:    10
*label2.y:    130
*label2.height:    30
*label2.width:    320
*label2.marginHeight:    0
*label2.marginWidth:    0
*label2.fontList:            courB12
!*label3.labelString:    /usr/lib/X11/app-defaults/Pathtest
*label3.x:    10
*label3.y:    170
*label3.height:    30
*label3.width:    320
*label3.marginHeight:    0
*label3.marginWidth:    0
*label3.fontList:            courB12

/*  include files  */

#include <stdio.h>
#include <Xm/PushB.h>
#include <Xm/Label.h>
#include <Xm/BulletinB.h>


/*  Functions defined in this program  */

void main();
void activateCB(); /* Callback for the PushButton */


/*  Global variables  */

XmString btn_text;    /* button label pointer for compound string */


/*-------------------------------------------------------------
**    main - Main logic for xmbutton
*/
void main (argc,argv)
unsigned int argc;
char **argv;
{
    Widget       toplevel;                   /*  Shell widget         */
    Widget       bboard;                     /*  Bulletin board widget */
    Widget       button;                     /*  PushButton widget    */
    Widget       label1, label2, label3;     /*  Label widgets        */
    Arg          args[10];    /*  arg list             */
    register     int n;       /*  arg count            */
    XtAppContext app_context; /*  application context  */

/*  Initialize the toolkit, create application context, open display, 
    and  create a toplevel shell.  Note that Pathtest is the application
    class name that is used as the file name for app-defaults files for
    this application.                                                 */

    toplevel = XtAppInitialize (&app_context, "Pathtest", NULL, 0, &argc, argv,
    NULL, args, 0);

/*  Create a bulletin board widget in which to place the pushbutton
    and the three label widgets.                                   */
    n = 0;
    bboard = XmCreateBulletinBoard (toplevel, "bboard", args, n);

/*  Manage the bulletin board widget */
    XtManageChild (bboard);

/*  Create a compound string for the pushbutton text  */
    btn_text = XmStringCreateLtoR("Quit", XmSTRING_DEFAULT_CHARSET);

/*  Set up an arglist for the pushbutton  */
    n = 0;
    XtSetArg (args[n], XmNlabelString, btn_text);  n++;

/*  Create the pushbutton */
    button = XmCreatePushButton (bboard, "button", args, n); 
    
/*  Manage the pushbutton */
    XtManageChild (button);

/*  Add a callback for the pushbutton */
    XtAddCallback (button, XmNactivateCallback, activateCB, NULL);

/*  Create label1 */
    n = 0;
    label1 =  XmCreateLabel (bboard, "label1", args, n); 
    
/*  Manage label1 */
    XtManageChild (label1);

/*  Create label2 */
    n = 0;
    label2 =  XmCreateLabel (bboard, "label2", args, n); 
    
/*  Manage label2 */
    XtManageChild (label2);

/*  Create label3 */
    n = 0;
    label3 =  XmCreateLabel (bboard, "label3", args, n); 
    
/*  Manage label3 */
    XtManageChild (label3);

/*  Realize widgets  */
    XtRealizeWidget (toplevel);

/*  Process events  */
    XtAppMainLoop (app_context);
}


/*-------------------------------------------------------------
**    activateCB - callback for button
*/
void activateCB (w, client_data, call_data) 
    Widget     w;            /*  widget id              */
    XtPointer     client_data;  /*  data from application  */
    XtPointer     call_data;    /*  data from widget class */
{
/*  Print message, free compound string memory, and terminate program  */
    printf ("Pushbutton Activated.\n");
    XtFree(btn_text);
    exit (0);
}

